@@ -11,7 +11,8 @@ class S3:
         '.jpg': 'image/jpeg',
         '.svg': 'image/svg+xml',
         '.png': 'image/png',
-        '.txt': 'text/plain'
+        '.txt': 'text/plain',
+        '.log': 'text/plain',
     }
 
     def __init__(self, bucket, *args, **kwargs):
