@@ -10,6 +10,7 @@ logging.getLogger("amqp").setLevel(logging.WARNING)
 logging.getLogger("botocore").setLevel(logging.WARNING)
 logging.getLogger("boto3").setLevel(logging.WARNING)
 logging.getLogger("s3transfer").setLevel(logging.WARNING)
+logging.getLogger("celery").setLevel(logging.ERROR)
 
 
 def configure_logger(log_dir, level="DEBUG"):
@@ -35,7 +36,7 @@ def configure_logger(log_dir, level="DEBUG"):
                 'level': level,
                 'formatter': 'standard',
                 'class': 'logging.FileHandler',
-                'filename': log_dir / 'app.log'
+                'filename': log_dir / 'task.log'
             },
         },
         'loggers': {
